pub enum BlobTransactionSidecarVariant {
Eip4844(BlobTransactionSidecar),
Eip7594(BlobTransactionSidecarEip7594),
}Expand description
This represents a set of blobs, and its corresponding commitments and proofs. Proof type depends on the sidecar variant.
This type encodes and decodes the fields without an rlp header.
Variants
Eip4844(BlobTransactionSidecar)
EIP-4844 style blob transaction sidecar.
Eip7594(BlobTransactionSidecarEip7594)
EIP-7594 style blob transaction sidecar with cell proofs.
Implementations
Sourceimpl BlobTransactionSidecarVariant
impl BlobTransactionSidecarVariant
Sourcepub const fn is_eip4844(&self) -> bool
pub const fn is_eip4844(&self) -> bool
Returns true if this is a BlobTransactionSidecarVariant::Eip4844.
Sourcepub const fn is_eip7594(&self) -> bool
pub const fn is_eip7594(&self) -> bool
Returns true if this is a BlobTransactionSidecarVariant::Eip7594.
Sourcepub const fn as_eip4844(&self) -> Option<&BlobTransactionSidecar>
pub const fn as_eip4844(&self) -> Option<&BlobTransactionSidecar>
Returns the EIP-4844 sidecar if it is Self::Eip4844.
Sourcepub const fn as_eip7594(&self) -> Option<&BlobTransactionSidecarEip7594>
pub const fn as_eip7594(&self) -> Option<&BlobTransactionSidecarEip7594>
Returns the EIP-7594 sidecar if it is Self::Eip7594.
Sourcepub fn into_eip4844(self) -> Option<BlobTransactionSidecar>
pub fn into_eip4844(self) -> Option<BlobTransactionSidecar>
Converts into EIP-4844 sidecar if it is Self::Eip4844.
Sourcepub fn into_eip7594(self) -> Option<BlobTransactionSidecarEip7594>
pub fn into_eip7594(self) -> Option<BlobTransactionSidecarEip7594>
Converts the EIP-7594 sidecar if it is Self::Eip7594.
Sourcepub fn blobs(&self) -> &[FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>]
pub fn blobs(&self) -> &[FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>]
Get a reference to the blobs
Sourcepub fn into_blobs(
self,
) -> Vec<FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>>
pub fn into_blobs( self, ) -> Vec<FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>>
Consume self and return the blobs
Sourcepub const fn size(&self) -> usize
pub const fn size(&self) -> usize
Calculates a size heuristic for the in-memory size of the BlobTransactionSidecarVariant.
Sourcepub fn try_convert_into_eip7594(
self,
) -> Result<BlobTransactionSidecarVariant, Error>
Available on crate feature kzg only.
pub fn try_convert_into_eip7594( self, ) -> Result<BlobTransactionSidecarVariant, Error>
kzg only.Attempts to convert this sidecar into the EIP-7594 format using default KZG settings.
This method converts an EIP-4844 sidecar to EIP-7594 by computing cell KZG proofs from the blob data. If the sidecar is already in EIP-7594 format, it returns itself unchanged.
The conversion requires computing CELLS_PER_EXT_BLOB cell proofs for each blob using
the KZG trusted setup. The default KZG settings are loaded from the environment.
Returns
Ok(Self)- The sidecar in EIP-7594 format (either converted or unchanged)Err(c_kzg::Error)- If KZG proof computation fails
Examples
// Convert an EIP-4844 sidecar to EIP-7594 format
let eip7594_sidecar = sidecar.try_convert_into_eip7594()?;
// Verify it's now in EIP-7594 format
assert!(eip7594_sidecar.is_eip7594());Sourcepub fn try_convert_into_eip7594_with_settings(
self,
settings: &KZGSettings,
) -> Result<BlobTransactionSidecarVariant, Error>
Available on crate feature kzg only.
pub fn try_convert_into_eip7594_with_settings( self, settings: &KZGSettings, ) -> Result<BlobTransactionSidecarVariant, Error>
kzg only.Attempts to convert this sidecar into the EIP-7594 format using custom KZG settings.
This method converts an EIP-4844 sidecar to EIP-7594 by computing cell KZG proofs from the blob data using the provided KZG settings. If the sidecar is already in EIP-7594 format, it returns itself unchanged.
The conversion requires computing CELLS_PER_EXT_BLOB cell proofs for each blob using
the provided KZG trusted setup parameters.
Use this method when you need to specify custom KZG settings rather than using the
defaults. For most use cases, try_convert_into_eip7594
is sufficient.
Arguments
settings- The KZG settings to use for computing cell proofs
Returns
Ok(Self)- The sidecar in EIP-7594 format (either converted or unchanged)Err(c_kzg::Error)- If KZG proof computation fails
Examples
// Load custom KZG settings
let kzg_settings = EnvKzgSettings::Default.get();
// Convert using custom settings
let eip7594_sidecar = sidecar.try_convert_into_eip7594_with_settings(kzg_settings)?;
// Verify it's now in EIP-7594 format
assert!(eip7594_sidecar.is_eip7594());Sourcepub fn try_into_eip7594(self) -> Result<BlobTransactionSidecarEip7594, Error>
Available on crate feature kzg only.
pub fn try_into_eip7594(self) -> Result<BlobTransactionSidecarEip7594, Error>
kzg only.Consumes this sidecar and returns a BlobTransactionSidecarEip7594 using default KZG
settings.
This method converts an EIP-4844 sidecar to EIP-7594 by computing cell KZG proofs from
the blob data. If the sidecar is already in EIP-7594 format, it extracts and returns the
inner BlobTransactionSidecarEip7594.
Unlike try_convert_into_eip7594, this method returns
the concrete BlobTransactionSidecarEip7594 type rather than the enum variant.
The conversion requires computing CELLS_PER_EXT_BLOB cell proofs for each blob using
the KZG trusted setup. The default KZG settings are loaded from the environment.
Returns
Ok(BlobTransactionSidecarEip7594)- The sidecar in EIP-7594 formatErr(c_kzg::Error)- If KZG proof computation fails
Examples
// Convert and extract the EIP-7594 sidecar
let eip7594_sidecar = sidecar.try_into_eip7594()?;
// Now we have the concrete BlobTransactionSidecarEip7594 type
assert_eq!(eip7594_sidecar.blobs.len(), eip7594_sidecar.commitments.len());Sourcepub fn try_into_eip7594_with_settings(
self,
settings: &KZGSettings,
) -> Result<BlobTransactionSidecarEip7594, Error>
Available on crate feature kzg only.
pub fn try_into_eip7594_with_settings( self, settings: &KZGSettings, ) -> Result<BlobTransactionSidecarEip7594, Error>
kzg only.Consumes this sidecar and returns a BlobTransactionSidecarEip7594 using custom KZG
settings.
This method converts an EIP-4844 sidecar to EIP-7594 by computing cell KZG proofs from
the blob data using the provided KZG settings. If the sidecar is already in EIP-7594
format, it extracts and returns the inner BlobTransactionSidecarEip7594.
Unlike try_convert_into_eip7594_with_settings,
this method returns the concrete BlobTransactionSidecarEip7594 type rather than the
enum variant.
The conversion requires computing CELLS_PER_EXT_BLOB cell proofs for each blob using
the provided KZG trusted setup parameters.
Use this method when you need to specify custom KZG settings rather than using the
defaults. For most use cases, try_into_eip7594 is sufficient.
Arguments
settings- The KZG settings to use for computing cell proofs
Returns
Ok(BlobTransactionSidecarEip7594)- The sidecar in EIP-7594 formatErr(c_kzg::Error)- If KZG proof computation fails
Examples
// Load custom KZG settings
let kzg_settings = EnvKzgSettings::Default.get();
// Convert and extract using custom settings
let eip7594_sidecar = sidecar.try_into_eip7594_with_settings(kzg_settings)?;
// Now we have the concrete BlobTransactionSidecarEip7594 type
assert_eq!(eip7594_sidecar.blobs.len(), eip7594_sidecar.commitments.len());Sourcepub fn validate(
&self,
blob_versioned_hashes: &[FixedBytes<32>],
proof_settings: &KZGSettings,
) -> Result<(), BlobTransactionValidationError>
Available on crate feature kzg only.
pub fn validate( &self, blob_versioned_hashes: &[FixedBytes<32>], proof_settings: &KZGSettings, ) -> Result<(), BlobTransactionValidationError>
kzg only.Verifies that the sidecar is valid. See relevant methods for each variant for more info.
Sourcepub fn commitments(&self) -> &[FixedBytes<48>]
pub fn commitments(&self) -> &[FixedBytes<48>]
Returns the commitments of the sidecar.
Sourcepub fn versioned_hashes(&self) -> VersionedHashIter<'_>
pub fn versioned_hashes(&self) -> VersionedHashIter<'_>
Returns an iterator over the versioned hashes of the commitments.
Sourcepub fn versioned_hash_index(&self, hash: &FixedBytes<32>) -> Option<usize>
pub fn versioned_hash_index(&self, hash: &FixedBytes<32>) -> Option<usize>
Returns the index of the versioned hash in the commitments vector.
Sourcepub fn blob_by_versioned_hash(
&self,
hash: &FixedBytes<32>,
) -> Option<&FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>>
pub fn blob_by_versioned_hash( &self, hash: &FixedBytes<32>, ) -> Option<&FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>>
Returns the blob corresponding to the versioned hash, if it exists.